@@ -1,5 +1,20 @@
 .pkgenv <- new.env(parent = emptyenv())
 
+# # RETICULATE : https://cran.r-project.org/web/packages/reticulate/vignettes/package.html
+# numpy      <- NULL
+# cython     <- NULL
+# matplotlib <- NULL
+# ot         <- NULL
+# 
+# .onLoad <- function(libname, pkgname){
+#   # use superassignment to update global reference
+#   numpy <<- reticulate::import("numpy", delay_load = TRUE)
+#   cython <<- reticulate::import("cython", delay_load = TRUE)
+#   matplotlib <<- reticulate::import("matplotlib", delay_load = TRUE)
+#   ot    <<- reticulate::import("ot",    delay_load = TRUE)
+#   reticulate::configure_environment(pkgname)
+# }
+
 .onAttach <- function(...){
   ## Retrieve Year Information
   date <- date()
@@ -13,9 +28,9 @@
   packageStartupMessage("** ------------------------------------------------------- **")
   packageStartupMessage("**   T4transport || Computational Optimal Transport in R ")
   packageStartupMessage("**")
+  packageStartupMessage("** Maintainer : Kisung You  (kisungyou@outlook.com)")
   packageStartupMessage("** Version    : ",this.version,"       (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You  (kyoustat@gmail.com)")
-  packageStartupMessage("** Website    : https://kyoustat.com/T4transport/")
+  packageStartupMessage("** Website    : https://kisungyou.com/T4transport/")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
   packageStartupMessage("** ------------------------------------------------------- **")
